/*
 * Copyright (c) 2020, Oracle and/or its affiliates.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License, version 2.0,
 * as published by the Free Software Foundation.
 *
 * This program is also distributed with certain software (including
 * but not limited to OpenSSL) that is licensed under separate terms, as
 * designated in a particular file or component or in included license
 * documentation.  The authors of MySQL hereby grant you an additional
 * permission to link the program and your derivative works with the
 * separately licensed software that they have included with MySQL.
 * This program is distributed in the hope that it will be useful,  but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
 * the GNU General Public License, version 2.0, for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 */

#include "mysqlshdk/libs/utils/utils_time.h"

#include "mysqlshdk/libs/utils/strformat.h"

namespace shcore {

std::string current_time_rfc3339() {
  return future_time_rfc3339(std::chrono::hours(0));
}

std::string future_time_rfc3339(const std::chrono::hours &h) {
  const auto current_time = std::chrono::system_clock::to_time_t(
      std::chrono::system_clock::now() + h);

  return mysqlshdk::utils::fmttime("%FT%TZ", mysqlshdk::utils::Time_type::GMT,
                                   &current_time);
}

}  // namespace shcore
